# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stellarstation/api/v1/common/common.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='stellarstation/api/v1/common/common.proto',
  package='stellarstation.api.v1.common',
  syntax='proto3',
  serialized_options=_b('\n com.stellarstation.api.v1.commonB\013CommonProtoP\001Z9github.com/infostellarinc/go-stellarstation/api/v1/common'),
  serialized_pb=_b('\n)stellarstation/api/v1/common/common.proto\x12\x1cstellarstation.api.v1.common\"\'\n\x04\x42its\x12\x0e\n\x06length\x18\x01 \x01(\r\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\x42l\n com.stellarstation.api.v1.commonB\x0b\x43ommonProtoP\x01Z9github.com/infostellarinc/go-stellarstation/api/v1/commonb\x06proto3')
)




_BITS = _descriptor.Descriptor(
  name='Bits',
  full_name='stellarstation.api.v1.common.Bits',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='length', full_name='stellarstation.api.v1.common.Bits.length', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payload', full_name='stellarstation.api.v1.common.Bits.payload', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=75,
  serialized_end=114,
)

DESCRIPTOR.message_types_by_name['Bits'] = _BITS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Bits = _reflection.GeneratedProtocolMessageType('Bits', (_message.Message,), dict(
  DESCRIPTOR = _BITS,
  __module__ = 'stellarstation.api.v1.common.common_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.common.Bits)
  ))
_sym_db.RegisterMessage(Bits)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
