# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stellarstation/api/v1/groundstation/groundstation.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from stellarstation.api.v1.radio import radio_pb2 as stellarstation_dot_api_dot_v1_dot_radio_dot_radio__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='stellarstation/api/v1/groundstation/groundstation.proto',
  package='stellarstation.api.v1.groundstation',
  syntax='proto3',
  serialized_options=_b('\n\'com.stellarstation.api.v1.groundstationB\022GroundStationProtoP\001Z@github.com/infostellarinc/go-stellarstation/api/v1/groundstation'),
  serialized_pb=_b('\n7stellarstation/api/v1/groundstation/groundstation.proto\x12#stellarstation.api.v1.groundstation\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\'stellarstation/api/v1/radio/radio.proto\"\x8c\x01\n\x10ListPlansRequest\x12\x19\n\x11ground_station_id\x18\x01 \x01(\t\x12-\n\taos_after\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\naos_before\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"L\n\x11ListPlansResponse\x12\x37\n\x04plan\x18\x01 \x03(\x0b\x32).stellarstation.api.v1.groundstation.Plan\"\xd4\x02\n\x04Plan\x12\x0f\n\x07plan_id\x18\x01 \x01(\t\x12\x35\n\x03tle\x18\x02 \x01(\x0b\x32(.stellarstation.api.v1.groundstation.Tle\x12,\n\x08\x61os_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08los_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12T\n\x15\x64ownlink_radio_device\x18\x05 \x01(\x0b\x32\x35.stellarstation.api.v1.radio.RadioDeviceConfiguration\x12R\n\x13uplink_radio_device\x18\x06 \x01(\x0b\x32\x35.stellarstation.api.v1.radio.RadioDeviceConfiguration\"%\n\x03Tle\x12\x0e\n\x06line_1\x18\x01 \x01(\t\x12\x0e\n\x06line_2\x18\x02 \x01(\t\"\x87\x01\n\x14UnavailabilityWindow\x12\x11\n\twindow_id\x18\x01 \x01(\t\x12.\n\nstart_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x9b\x01\n ListUnavailabilityWindowsRequest\x12\x19\n\x11ground_station_id\x18\x01 \x01(\t\x12.\n\nstart_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"n\n!ListUnavailabilityWindowsResponse\x12I\n\x06window\x18\x01 \x03(\x0b\x32\x39.stellarstation.api.v1.groundstation.UnavailabilityWindow\"\x99\x01\n\x1e\x41\x64\x64UnavailabilityWindowRequest\x12\x19\n\x11ground_station_id\x18\x01 \x01(\t\x12.\n\nstart_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"4\n\x1f\x41\x64\x64UnavailabilityWindowResponse\x12\x11\n\twindow_id\x18\x01 \x01(\t\"6\n!DeleteUnavailabilityWindowRequest\x12\x11\n\twindow_id\x18\x01 \x01(\t\"$\n\"DeleteUnavailabilityWindowResponse2\x96\x05\n\x14GroundStationService\x12\xa4\x01\n\x17\x41\x64\x64UnavailabilityWindow\x12\x43.stellarstation.api.v1.groundstation.AddUnavailabilityWindowRequest\x1a\x44.stellarstation.api.v1.groundstation.AddUnavailabilityWindowResponse\x12\xad\x01\n\x1a\x44\x65leteUnavailabilityWindow\x12\x46.stellarstation.api.v1.groundstation.DeleteUnavailabilityWindowRequest\x1aG.stellarstation.api.v1.groundstation.DeleteUnavailabilityWindowResponse\x12z\n\tListPlans\x12\x35.stellarstation.api.v1.groundstation.ListPlansRequest\x1a\x36.stellarstation.api.v1.groundstation.ListPlansResponse\x12\xaa\x01\n\x19ListUnavailabilityWindows\x12\x45.stellarstation.api.v1.groundstation.ListUnavailabilityWindowsRequest\x1a\x46.stellarstation.api.v1.groundstation.ListUnavailabilityWindowsResponseB\x81\x01\n\'com.stellarstation.api.v1.groundstationB\x12GroundStationProtoP\x01Z@github.com/infostellarinc/go-stellarstation/api/v1/groundstationb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,stellarstation_dot_api_dot_v1_dot_radio_dot_radio__pb2.DESCRIPTOR,])




_LISTPLANSREQUEST = _descriptor.Descriptor(
  name='ListPlansRequest',
  full_name='stellarstation.api.v1.groundstation.ListPlansRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ground_station_id', full_name='stellarstation.api.v1.groundstation.ListPlansRequest.ground_station_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aos_after', full_name='stellarstation.api.v1.groundstation.ListPlansRequest.aos_after', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aos_before', full_name='stellarstation.api.v1.groundstation.ListPlansRequest.aos_before', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=171,
  serialized_end=311,
)


_LISTPLANSRESPONSE = _descriptor.Descriptor(
  name='ListPlansResponse',
  full_name='stellarstation.api.v1.groundstation.ListPlansResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='plan', full_name='stellarstation.api.v1.groundstation.ListPlansResponse.plan', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=313,
  serialized_end=389,
)


_PLAN = _descriptor.Descriptor(
  name='Plan',
  full_name='stellarstation.api.v1.groundstation.Plan',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='plan_id', full_name='stellarstation.api.v1.groundstation.Plan.plan_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tle', full_name='stellarstation.api.v1.groundstation.Plan.tle', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aos_time', full_name='stellarstation.api.v1.groundstation.Plan.aos_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='los_time', full_name='stellarstation.api.v1.groundstation.Plan.los_time', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='downlink_radio_device', full_name='stellarstation.api.v1.groundstation.Plan.downlink_radio_device', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uplink_radio_device', full_name='stellarstation.api.v1.groundstation.Plan.uplink_radio_device', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=392,
  serialized_end=732,
)


_TLE = _descriptor.Descriptor(
  name='Tle',
  full_name='stellarstation.api.v1.groundstation.Tle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='line_1', full_name='stellarstation.api.v1.groundstation.Tle.line_1', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_2', full_name='stellarstation.api.v1.groundstation.Tle.line_2', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=734,
  serialized_end=771,
)


_UNAVAILABILITYWINDOW = _descriptor.Descriptor(
  name='UnavailabilityWindow',
  full_name='stellarstation.api.v1.groundstation.UnavailabilityWindow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='window_id', full_name='stellarstation.api.v1.groundstation.UnavailabilityWindow.window_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='stellarstation.api.v1.groundstation.UnavailabilityWindow.start_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='stellarstation.api.v1.groundstation.UnavailabilityWindow.end_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=774,
  serialized_end=909,
)


_LISTUNAVAILABILITYWINDOWSREQUEST = _descriptor.Descriptor(
  name='ListUnavailabilityWindowsRequest',
  full_name='stellarstation.api.v1.groundstation.ListUnavailabilityWindowsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ground_station_id', full_name='stellarstation.api.v1.groundstation.ListUnavailabilityWindowsRequest.ground_station_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='stellarstation.api.v1.groundstation.ListUnavailabilityWindowsRequest.start_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='stellarstation.api.v1.groundstation.ListUnavailabilityWindowsRequest.end_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=912,
  serialized_end=1067,
)


_LISTUNAVAILABILITYWINDOWSRESPONSE = _descriptor.Descriptor(
  name='ListUnavailabilityWindowsResponse',
  full_name='stellarstation.api.v1.groundstation.ListUnavailabilityWindowsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='window', full_name='stellarstation.api.v1.groundstation.ListUnavailabilityWindowsResponse.window', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1069,
  serialized_end=1179,
)


_ADDUNAVAILABILITYWINDOWREQUEST = _descriptor.Descriptor(
  name='AddUnavailabilityWindowRequest',
  full_name='stellarstation.api.v1.groundstation.AddUnavailabilityWindowRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ground_station_id', full_name='stellarstation.api.v1.groundstation.AddUnavailabilityWindowRequest.ground_station_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='stellarstation.api.v1.groundstation.AddUnavailabilityWindowRequest.start_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='stellarstation.api.v1.groundstation.AddUnavailabilityWindowRequest.end_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1182,
  serialized_end=1335,
)


_ADDUNAVAILABILITYWINDOWRESPONSE = _descriptor.Descriptor(
  name='AddUnavailabilityWindowResponse',
  full_name='stellarstation.api.v1.groundstation.AddUnavailabilityWindowResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='window_id', full_name='stellarstation.api.v1.groundstation.AddUnavailabilityWindowResponse.window_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1337,
  serialized_end=1389,
)


_DELETEUNAVAILABILITYWINDOWREQUEST = _descriptor.Descriptor(
  name='DeleteUnavailabilityWindowRequest',
  full_name='stellarstation.api.v1.groundstation.DeleteUnavailabilityWindowRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='window_id', full_name='stellarstation.api.v1.groundstation.DeleteUnavailabilityWindowRequest.window_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1391,
  serialized_end=1445,
)


_DELETEUNAVAILABILITYWINDOWRESPONSE = _descriptor.Descriptor(
  name='DeleteUnavailabilityWindowResponse',
  full_name='stellarstation.api.v1.groundstation.DeleteUnavailabilityWindowResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1447,
  serialized_end=1483,
)

_LISTPLANSREQUEST.fields_by_name['aos_after'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTPLANSREQUEST.fields_by_name['aos_before'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTPLANSRESPONSE.fields_by_name['plan'].message_type = _PLAN
_PLAN.fields_by_name['tle'].message_type = _TLE
_PLAN.fields_by_name['aos_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PLAN.fields_by_name['los_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PLAN.fields_by_name['downlink_radio_device'].message_type = stellarstation_dot_api_dot_v1_dot_radio_dot_radio__pb2._RADIODEVICECONFIGURATION
_PLAN.fields_by_name['uplink_radio_device'].message_type = stellarstation_dot_api_dot_v1_dot_radio_dot_radio__pb2._RADIODEVICECONFIGURATION
_UNAVAILABILITYWINDOW.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_UNAVAILABILITYWINDOW.fields_by_name['end_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTUNAVAILABILITYWINDOWSREQUEST.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTUNAVAILABILITYWINDOWSREQUEST.fields_by_name['end_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTUNAVAILABILITYWINDOWSRESPONSE.fields_by_name['window'].message_type = _UNAVAILABILITYWINDOW
_ADDUNAVAILABILITYWINDOWREQUEST.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ADDUNAVAILABILITYWINDOWREQUEST.fields_by_name['end_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['ListPlansRequest'] = _LISTPLANSREQUEST
DESCRIPTOR.message_types_by_name['ListPlansResponse'] = _LISTPLANSRESPONSE
DESCRIPTOR.message_types_by_name['Plan'] = _PLAN
DESCRIPTOR.message_types_by_name['Tle'] = _TLE
DESCRIPTOR.message_types_by_name['UnavailabilityWindow'] = _UNAVAILABILITYWINDOW
DESCRIPTOR.message_types_by_name['ListUnavailabilityWindowsRequest'] = _LISTUNAVAILABILITYWINDOWSREQUEST
DESCRIPTOR.message_types_by_name['ListUnavailabilityWindowsResponse'] = _LISTUNAVAILABILITYWINDOWSRESPONSE
DESCRIPTOR.message_types_by_name['AddUnavailabilityWindowRequest'] = _ADDUNAVAILABILITYWINDOWREQUEST
DESCRIPTOR.message_types_by_name['AddUnavailabilityWindowResponse'] = _ADDUNAVAILABILITYWINDOWRESPONSE
DESCRIPTOR.message_types_by_name['DeleteUnavailabilityWindowRequest'] = _DELETEUNAVAILABILITYWINDOWREQUEST
DESCRIPTOR.message_types_by_name['DeleteUnavailabilityWindowResponse'] = _DELETEUNAVAILABILITYWINDOWRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListPlansRequest = _reflection.GeneratedProtocolMessageType('ListPlansRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTPLANSREQUEST,
  __module__ = 'stellarstation.api.v1.groundstation.groundstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.ListPlansRequest)
  ))
_sym_db.RegisterMessage(ListPlansRequest)

ListPlansResponse = _reflection.GeneratedProtocolMessageType('ListPlansResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTPLANSRESPONSE,
  __module__ = 'stellarstation.api.v1.groundstation.groundstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.ListPlansResponse)
  ))
_sym_db.RegisterMessage(ListPlansResponse)

Plan = _reflection.GeneratedProtocolMessageType('Plan', (_message.Message,), dict(
  DESCRIPTOR = _PLAN,
  __module__ = 'stellarstation.api.v1.groundstation.groundstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.Plan)
  ))
_sym_db.RegisterMessage(Plan)

Tle = _reflection.GeneratedProtocolMessageType('Tle', (_message.Message,), dict(
  DESCRIPTOR = _TLE,
  __module__ = 'stellarstation.api.v1.groundstation.groundstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.Tle)
  ))
_sym_db.RegisterMessage(Tle)

UnavailabilityWindow = _reflection.GeneratedProtocolMessageType('UnavailabilityWindow', (_message.Message,), dict(
  DESCRIPTOR = _UNAVAILABILITYWINDOW,
  __module__ = 'stellarstation.api.v1.groundstation.groundstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.UnavailabilityWindow)
  ))
_sym_db.RegisterMessage(UnavailabilityWindow)

ListUnavailabilityWindowsRequest = _reflection.GeneratedProtocolMessageType('ListUnavailabilityWindowsRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTUNAVAILABILITYWINDOWSREQUEST,
  __module__ = 'stellarstation.api.v1.groundstation.groundstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.ListUnavailabilityWindowsRequest)
  ))
_sym_db.RegisterMessage(ListUnavailabilityWindowsRequest)

ListUnavailabilityWindowsResponse = _reflection.GeneratedProtocolMessageType('ListUnavailabilityWindowsResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTUNAVAILABILITYWINDOWSRESPONSE,
  __module__ = 'stellarstation.api.v1.groundstation.groundstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.ListUnavailabilityWindowsResponse)
  ))
_sym_db.RegisterMessage(ListUnavailabilityWindowsResponse)

AddUnavailabilityWindowRequest = _reflection.GeneratedProtocolMessageType('AddUnavailabilityWindowRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDUNAVAILABILITYWINDOWREQUEST,
  __module__ = 'stellarstation.api.v1.groundstation.groundstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.AddUnavailabilityWindowRequest)
  ))
_sym_db.RegisterMessage(AddUnavailabilityWindowRequest)

AddUnavailabilityWindowResponse = _reflection.GeneratedProtocolMessageType('AddUnavailabilityWindowResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDUNAVAILABILITYWINDOWRESPONSE,
  __module__ = 'stellarstation.api.v1.groundstation.groundstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.AddUnavailabilityWindowResponse)
  ))
_sym_db.RegisterMessage(AddUnavailabilityWindowResponse)

DeleteUnavailabilityWindowRequest = _reflection.GeneratedProtocolMessageType('DeleteUnavailabilityWindowRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEUNAVAILABILITYWINDOWREQUEST,
  __module__ = 'stellarstation.api.v1.groundstation.groundstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.DeleteUnavailabilityWindowRequest)
  ))
_sym_db.RegisterMessage(DeleteUnavailabilityWindowRequest)

DeleteUnavailabilityWindowResponse = _reflection.GeneratedProtocolMessageType('DeleteUnavailabilityWindowResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETEUNAVAILABILITYWINDOWRESPONSE,
  __module__ = 'stellarstation.api.v1.groundstation.groundstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.DeleteUnavailabilityWindowResponse)
  ))
_sym_db.RegisterMessage(DeleteUnavailabilityWindowResponse)


DESCRIPTOR._options = None

_GROUNDSTATIONSERVICE = _descriptor.ServiceDescriptor(
  name='GroundStationService',
  full_name='stellarstation.api.v1.groundstation.GroundStationService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1486,
  serialized_end=2148,
  methods=[
  _descriptor.MethodDescriptor(
    name='AddUnavailabilityWindow',
    full_name='stellarstation.api.v1.groundstation.GroundStationService.AddUnavailabilityWindow',
    index=0,
    containing_service=None,
    input_type=_ADDUNAVAILABILITYWINDOWREQUEST,
    output_type=_ADDUNAVAILABILITYWINDOWRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteUnavailabilityWindow',
    full_name='stellarstation.api.v1.groundstation.GroundStationService.DeleteUnavailabilityWindow',
    index=1,
    containing_service=None,
    input_type=_DELETEUNAVAILABILITYWINDOWREQUEST,
    output_type=_DELETEUNAVAILABILITYWINDOWRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListPlans',
    full_name='stellarstation.api.v1.groundstation.GroundStationService.ListPlans',
    index=2,
    containing_service=None,
    input_type=_LISTPLANSREQUEST,
    output_type=_LISTPLANSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListUnavailabilityWindows',
    full_name='stellarstation.api.v1.groundstation.GroundStationService.ListUnavailabilityWindows',
    index=3,
    containing_service=None,
    input_type=_LISTUNAVAILABILITYWINDOWSREQUEST,
    output_type=_LISTUNAVAILABILITYWINDOWSRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_GROUNDSTATIONSERVICE)

DESCRIPTOR.services_by_name['GroundStationService'] = _GROUNDSTATIONSERVICE

# @@protoc_insertion_point(module_scope)
