# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stellarstation/api/v1/stellarstation.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from stellarstation.api.v1.monitoring import monitoring_pb2 as stellarstation_dot_api_dot_v1_dot_monitoring_dot_monitoring__pb2
from stellarstation.api.v1.orbit import orbit_pb2 as stellarstation_dot_api_dot_v1_dot_orbit_dot_orbit__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='stellarstation/api/v1/stellarstation.proto',
  package='stellarstation.api.v1',
  syntax='proto3',
  serialized_options=_b('\n\031com.stellarstation.api.v1B\023StellarstationProtoP\001Z2github.com/infostellarinc/go-stellarstation/api/v1'),
  serialized_pb=_b('\n*stellarstation/api/v1/stellarstation.proto\x12\x15stellarstation.api.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x31stellarstation/api/v1/monitoring/monitoring.proto\x1a\'stellarstation/api/v1/orbit/orbit.proto\"\x91\x02\n\x16SatelliteStreamRequest\x12\x14\n\x0csatellite_id\x18\x01 \x01(\t\x12\x11\n\tstream_id\x18\x02 \x01(\t\x12\x15\n\renable_events\x18\x05 \x01(\x08\x12\x12\n\nrequest_id\x18\x06 \x01(\t\x12^\n\x1fsend_satellite_commands_request\x18\x03 \x01(\x0b\x32\x33.stellarstation.api.v1.SendSatelliteCommandsRequestH\x00\x12\x38\n\x10\x61\x63\x63\x65pted_framing\x18\x04 \x03(\x0e\x32\x1e.stellarstation.api.v1.FramingB\t\n\x07Request\"/\n\x1cSendSatelliteCommandsRequest\x12\x0f\n\x07\x63ommand\x18\x02 \x03(\x0c\"\xcb\x01\n\x17SatelliteStreamResponse\x12\x11\n\tstream_id\x18\x01 \x01(\t\x12U\n\x1areceive_telemetry_response\x18\x02 \x01(\x0b\x32/.stellarstation.api.v1.ReceiveTelemetryResponseH\x00\x12:\n\x0cstream_event\x18\x03 \x01(\x0b\x32\".stellarstation.api.v1.StreamEventH\x00\x42\n\n\x08Response\"O\n\x18ReceiveTelemetryResponse\x12\x33\n\ttelemetry\x18\x01 \x01(\x0b\x32 .stellarstation.api.v1.Telemetry\"\xfa\x01\n\tTelemetry\x12/\n\x07\x66raming\x18\x01 \x01(\x0e\x32\x1e.stellarstation.api.v1.Framing\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x1d\n\x15\x64ownlink_frequency_hz\x18\x03 \x01(\x04\x12<\n\x18time_first_byte_received\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12;\n\x17time_last_byte_received\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0c\x66rame_header\x18\x06 \x01(\x0c\"\xea\x01\n\x13PlanMonitoringEvent\x12\x0f\n\x07plan_id\x18\x01 \x01(\t\x12\x64\n\x1cground_station_configuration\x18\x02 \x01(\x0b\x32<.stellarstation.api.v1.monitoring.GroundStationConfigurationH\x00\x12T\n\x14ground_station_state\x18\x03 \x01(\x0b\x32\x34.stellarstation.api.v1.monitoring.GroundStationStateH\x00\x42\x06\n\x04Info\"\xf0\x01\n\x0bStreamEvent\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12W\n\x0c\x63ommand_sent\x18\x02 \x01(\x0b\x32?.stellarstation.api.v1.StreamEvent.CommandSentFromGroundStationH\x00\x12K\n\x15plan_monitoring_event\x18\x03 \x01(\x0b\x32*.stellarstation.api.v1.PlanMonitoringEventH\x00\x1a\x1e\n\x1c\x43ommandSentFromGroundStationB\x07\n\x05\x45vent\"$\n\x11\x43\x61ncelPlanRequest\x12\x0f\n\x07plan_id\x18\x01 \x01(\t\"\x14\n\x12\x43\x61ncelPlanResponse\":\n\"ListUpcomingAvailablePassesRequest\x12\x14\n\x0csatellite_id\x18\x01 \x01(\t\"P\n#ListUpcomingAvailablePassesResponse\x12)\n\x04pass\x18\x01 \x03(\x0b\x32\x1b.stellarstation.api.v1.Pass\"/\n\x12ReservePassRequest\x12\x19\n\x11reservation_token\x18\x01 \x01(\t\"@\n\x13ReservePassResponse\x12)\n\x04plan\x18\x01 \x01(\x0b\x32\x1b.stellarstation.api.v1.Plan\"\x87\x01\n\x10ListPlansRequest\x12\x14\n\x0csatellite_id\x18\x01 \x01(\t\x12-\n\taos_after\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\naos_before\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\">\n\x11ListPlansResponse\x12)\n\x04plan\x18\x01 \x03(\x0b\x32\x1b.stellarstation.api.v1.Plan\"\x86\x03\n\x04Pass\x12\x19\n\x11reservation_token\x18\x01 \x01(\t\x12,\n\x08\x61os_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08los_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1f\n\x17ground_station_latitude\x18\x04 \x01(\x01\x12 \n\x18ground_station_longitude\x18\x05 \x01(\x01\x12#\n\x1bground_station_country_code\x18\x06 \x01(\t\x12\x1d\n\x15max_elevation_degrees\x18\x07 \x01(\x01\x12\x36\n\x12max_elevation_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12$\n\x1c\x64ownlink_center_frequency_hz\x18\t \x01(\x04\x12\"\n\x1auplink_center_frequency_hz\x18\n \x01(\x04\"\x99\x01\n\x11TelemetryMetadata\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x44\n\tdata_type\x18\x02 \x01(\x0e\x32\x31.stellarstation.api.v1.TelemetryMetadata.DataType\"1\n\x08\x44\x61taType\x12\x07\n\x03RAW\x10\x00\x12\x0f\n\x0b\x44\x45MODULATED\x10\x01\x12\x0b\n\x07\x44\x45\x43ODED\x10\x02\"\xe6\x04\n\x04Plan\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0csatellite_id\x18\x02 \x01(\t\x12\x32\n\x06status\x18\x03 \x01(\x0e\x32\".stellarstation.api.v1.Plan.Status\x12,\n\x08\x61os_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08los_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1f\n\x17ground_station_latitude\x18\x06 \x01(\x01\x12 \n\x18ground_station_longitude\x18\x07 \x01(\x01\x12#\n\x1bground_station_country_code\x18\x08 \x01(\t\x12\x1d\n\x15max_elevation_degrees\x18\t \x01(\x01\x12\x36\n\x12max_elevation_time\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12$\n\x1c\x64ownlink_center_frequency_hz\x18\x0b \x01(\x04\x12\"\n\x1auplink_center_frequency_hz\x18\x0c \x01(\x04\x12\x43\n\x11telmetry_metadata\x18\r \x03(\x0b\x32(.stellarstation.api.v1.TelemetryMetadata\"^\n\x06Status\x12\x0c\n\x08RESERVED\x10\x00\x12\r\n\tEXECUTING\x10\x01\x12\r\n\tSUCCEEDED\x10\x02\x12\n\n\x06\x46\x41ILED\x10\x03\x12\x0c\n\x08\x43\x41NCELED\x10\x04\x12\x0e\n\nPROCESSING\x10\x05\"T\n\rAddTleRequest\x12\x14\n\x0csatellite_id\x18\x01 \x01(\t\x12-\n\x03tle\x18\x02 \x01(\x0b\x32 .stellarstation.api.v1.orbit.Tle\"\x10\n\x0e\x41\x64\x64TleResponse\"%\n\rGetTleRequest\x12\x14\n\x0csatellite_id\x18\x01 \x01(\t\"?\n\x0eGetTleResponse\x12-\n\x03tle\x18\x01 \x01(\x0b\x32 .stellarstation.api.v1.orbit.Tle*9\n\x07\x46raming\x12\r\n\tBITSTREAM\x10\x00\x12\x08\n\x04\x41X25\x10\x01\x12\x06\n\x02IQ\x10\x02\x12\r\n\tIMAGE_PNG\x10\x03\x32\xff\x05\n\x15StellarStationService\x12^\n\tListPlans\x12\'.stellarstation.api.v1.ListPlansRequest\x1a(.stellarstation.api.v1.ListPlansResponse\x12\x61\n\nCancelPlan\x12(.stellarstation.api.v1.CancelPlanRequest\x1a).stellarstation.api.v1.CancelPlanResponse\x12\x94\x01\n\x1bListUpcomingAvailablePasses\x12\x39.stellarstation.api.v1.ListUpcomingAvailablePassesRequest\x1a:.stellarstation.api.v1.ListUpcomingAvailablePassesResponse\x12x\n\x13OpenSatelliteStream\x12-.stellarstation.api.v1.SatelliteStreamRequest\x1a..stellarstation.api.v1.SatelliteStreamResponse(\x01\x30\x01\x12\x64\n\x0bReservePass\x12).stellarstation.api.v1.ReservePassRequest\x1a*.stellarstation.api.v1.ReservePassResponse\x12U\n\x06\x41\x64\x64Tle\x12$.stellarstation.api.v1.AddTleRequest\x1a%.stellarstation.api.v1.AddTleResponse\x12U\n\x06GetTle\x12$.stellarstation.api.v1.GetTleRequest\x1a%.stellarstation.api.v1.GetTleResponseBf\n\x19\x63om.stellarstation.api.v1B\x13StellarstationProtoP\x01Z2github.com/infostellarinc/go-stellarstation/api/v1b\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,stellarstation_dot_api_dot_v1_dot_monitoring_dot_monitoring__pb2.DESCRIPTOR,stellarstation_dot_api_dot_v1_dot_orbit_dot_orbit__pb2.DESCRIPTOR,])

_FRAMING = _descriptor.EnumDescriptor(
  name='Framing',
  full_name='stellarstation.api.v1.Framing',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BITSTREAM', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AX25', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IQ', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IMAGE_PNG', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3432,
  serialized_end=3489,
)
_sym_db.RegisterEnumDescriptor(_FRAMING)

Framing = enum_type_wrapper.EnumTypeWrapper(_FRAMING)
BITSTREAM = 0
AX25 = 1
IQ = 2
IMAGE_PNG = 3


_TELEMETRYMETADATA_DATATYPE = _descriptor.EnumDescriptor(
  name='DataType',
  full_name='stellarstation.api.v1.TelemetryMetadata.DataType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RAW', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEMODULATED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DECODED', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2556,
  serialized_end=2605,
)
_sym_db.RegisterEnumDescriptor(_TELEMETRYMETADATA_DATATYPE)

_PLAN_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='stellarstation.api.v1.Plan.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESERVED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXECUTING', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUCCEEDED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANCELED', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROCESSING', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3128,
  serialized_end=3222,
)
_sym_db.RegisterEnumDescriptor(_PLAN_STATUS)


_SATELLITESTREAMREQUEST = _descriptor.Descriptor(
  name='SatelliteStreamRequest',
  full_name='stellarstation.api.v1.SatelliteStreamRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='satellite_id', full_name='stellarstation.api.v1.SatelliteStreamRequest.satellite_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stream_id', full_name='stellarstation.api.v1.SatelliteStreamRequest.stream_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enable_events', full_name='stellarstation.api.v1.SatelliteStreamRequest.enable_events', index=2,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='request_id', full_name='stellarstation.api.v1.SatelliteStreamRequest.request_id', index=3,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='send_satellite_commands_request', full_name='stellarstation.api.v1.SatelliteStreamRequest.send_satellite_commands_request', index=4,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='accepted_framing', full_name='stellarstation.api.v1.SatelliteStreamRequest.accepted_framing', index=5,
      number=4, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Request', full_name='stellarstation.api.v1.SatelliteStreamRequest.Request',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=195,
  serialized_end=468,
)


_SENDSATELLITECOMMANDSREQUEST = _descriptor.Descriptor(
  name='SendSatelliteCommandsRequest',
  full_name='stellarstation.api.v1.SendSatelliteCommandsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='stellarstation.api.v1.SendSatelliteCommandsRequest.command', index=0,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=470,
  serialized_end=517,
)


_SATELLITESTREAMRESPONSE = _descriptor.Descriptor(
  name='SatelliteStreamResponse',
  full_name='stellarstation.api.v1.SatelliteStreamResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stream_id', full_name='stellarstation.api.v1.SatelliteStreamResponse.stream_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='receive_telemetry_response', full_name='stellarstation.api.v1.SatelliteStreamResponse.receive_telemetry_response', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stream_event', full_name='stellarstation.api.v1.SatelliteStreamResponse.stream_event', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Response', full_name='stellarstation.api.v1.SatelliteStreamResponse.Response',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=520,
  serialized_end=723,
)


_RECEIVETELEMETRYRESPONSE = _descriptor.Descriptor(
  name='ReceiveTelemetryResponse',
  full_name='stellarstation.api.v1.ReceiveTelemetryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='telemetry', full_name='stellarstation.api.v1.ReceiveTelemetryResponse.telemetry', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=725,
  serialized_end=804,
)


_TELEMETRY = _descriptor.Descriptor(
  name='Telemetry',
  full_name='stellarstation.api.v1.Telemetry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='framing', full_name='stellarstation.api.v1.Telemetry.framing', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='stellarstation.api.v1.Telemetry.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='downlink_frequency_hz', full_name='stellarstation.api.v1.Telemetry.downlink_frequency_hz', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_first_byte_received', full_name='stellarstation.api.v1.Telemetry.time_first_byte_received', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_last_byte_received', full_name='stellarstation.api.v1.Telemetry.time_last_byte_received', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frame_header', full_name='stellarstation.api.v1.Telemetry.frame_header', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=807,
  serialized_end=1057,
)


_PLANMONITORINGEVENT = _descriptor.Descriptor(
  name='PlanMonitoringEvent',
  full_name='stellarstation.api.v1.PlanMonitoringEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='plan_id', full_name='stellarstation.api.v1.PlanMonitoringEvent.plan_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ground_station_configuration', full_name='stellarstation.api.v1.PlanMonitoringEvent.ground_station_configuration', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ground_station_state', full_name='stellarstation.api.v1.PlanMonitoringEvent.ground_station_state', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Info', full_name='stellarstation.api.v1.PlanMonitoringEvent.Info',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1060,
  serialized_end=1294,
)


_STREAMEVENT_COMMANDSENTFROMGROUNDSTATION = _descriptor.Descriptor(
  name='CommandSentFromGroundStation',
  full_name='stellarstation.api.v1.StreamEvent.CommandSentFromGroundStation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1498,
  serialized_end=1528,
)

_STREAMEVENT = _descriptor.Descriptor(
  name='StreamEvent',
  full_name='stellarstation.api.v1.StreamEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_id', full_name='stellarstation.api.v1.StreamEvent.request_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='command_sent', full_name='stellarstation.api.v1.StreamEvent.command_sent', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plan_monitoring_event', full_name='stellarstation.api.v1.StreamEvent.plan_monitoring_event', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_STREAMEVENT_COMMANDSENTFROMGROUNDSTATION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Event', full_name='stellarstation.api.v1.StreamEvent.Event',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1297,
  serialized_end=1537,
)


_CANCELPLANREQUEST = _descriptor.Descriptor(
  name='CancelPlanRequest',
  full_name='stellarstation.api.v1.CancelPlanRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='plan_id', full_name='stellarstation.api.v1.CancelPlanRequest.plan_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1539,
  serialized_end=1575,
)


_CANCELPLANRESPONSE = _descriptor.Descriptor(
  name='CancelPlanResponse',
  full_name='stellarstation.api.v1.CancelPlanResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1577,
  serialized_end=1597,
)


_LISTUPCOMINGAVAILABLEPASSESREQUEST = _descriptor.Descriptor(
  name='ListUpcomingAvailablePassesRequest',
  full_name='stellarstation.api.v1.ListUpcomingAvailablePassesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='satellite_id', full_name='stellarstation.api.v1.ListUpcomingAvailablePassesRequest.satellite_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1599,
  serialized_end=1657,
)


_LISTUPCOMINGAVAILABLEPASSESRESPONSE = _descriptor.Descriptor(
  name='ListUpcomingAvailablePassesResponse',
  full_name='stellarstation.api.v1.ListUpcomingAvailablePassesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pass', full_name='stellarstation.api.v1.ListUpcomingAvailablePassesResponse.pass', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1659,
  serialized_end=1739,
)


_RESERVEPASSREQUEST = _descriptor.Descriptor(
  name='ReservePassRequest',
  full_name='stellarstation.api.v1.ReservePassRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='reservation_token', full_name='stellarstation.api.v1.ReservePassRequest.reservation_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1741,
  serialized_end=1788,
)


_RESERVEPASSRESPONSE = _descriptor.Descriptor(
  name='ReservePassResponse',
  full_name='stellarstation.api.v1.ReservePassResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='plan', full_name='stellarstation.api.v1.ReservePassResponse.plan', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1790,
  serialized_end=1854,
)


_LISTPLANSREQUEST = _descriptor.Descriptor(
  name='ListPlansRequest',
  full_name='stellarstation.api.v1.ListPlansRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='satellite_id', full_name='stellarstation.api.v1.ListPlansRequest.satellite_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aos_after', full_name='stellarstation.api.v1.ListPlansRequest.aos_after', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aos_before', full_name='stellarstation.api.v1.ListPlansRequest.aos_before', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1857,
  serialized_end=1992,
)


_LISTPLANSRESPONSE = _descriptor.Descriptor(
  name='ListPlansResponse',
  full_name='stellarstation.api.v1.ListPlansResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='plan', full_name='stellarstation.api.v1.ListPlansResponse.plan', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1994,
  serialized_end=2056,
)


_PASS = _descriptor.Descriptor(
  name='Pass',
  full_name='stellarstation.api.v1.Pass',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='reservation_token', full_name='stellarstation.api.v1.Pass.reservation_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aos_time', full_name='stellarstation.api.v1.Pass.aos_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='los_time', full_name='stellarstation.api.v1.Pass.los_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ground_station_latitude', full_name='stellarstation.api.v1.Pass.ground_station_latitude', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ground_station_longitude', full_name='stellarstation.api.v1.Pass.ground_station_longitude', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ground_station_country_code', full_name='stellarstation.api.v1.Pass.ground_station_country_code', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_elevation_degrees', full_name='stellarstation.api.v1.Pass.max_elevation_degrees', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_elevation_time', full_name='stellarstation.api.v1.Pass.max_elevation_time', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='downlink_center_frequency_hz', full_name='stellarstation.api.v1.Pass.downlink_center_frequency_hz', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uplink_center_frequency_hz', full_name='stellarstation.api.v1.Pass.uplink_center_frequency_hz', index=9,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2059,
  serialized_end=2449,
)


_TELEMETRYMETADATA = _descriptor.Descriptor(
  name='TelemetryMetadata',
  full_name='stellarstation.api.v1.TelemetryMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='stellarstation.api.v1.TelemetryMetadata.url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_type', full_name='stellarstation.api.v1.TelemetryMetadata.data_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TELEMETRYMETADATA_DATATYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2452,
  serialized_end=2605,
)


_PLAN = _descriptor.Descriptor(
  name='Plan',
  full_name='stellarstation.api.v1.Plan',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='stellarstation.api.v1.Plan.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='satellite_id', full_name='stellarstation.api.v1.Plan.satellite_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='stellarstation.api.v1.Plan.status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aos_time', full_name='stellarstation.api.v1.Plan.aos_time', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='los_time', full_name='stellarstation.api.v1.Plan.los_time', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ground_station_latitude', full_name='stellarstation.api.v1.Plan.ground_station_latitude', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ground_station_longitude', full_name='stellarstation.api.v1.Plan.ground_station_longitude', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ground_station_country_code', full_name='stellarstation.api.v1.Plan.ground_station_country_code', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_elevation_degrees', full_name='stellarstation.api.v1.Plan.max_elevation_degrees', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_elevation_time', full_name='stellarstation.api.v1.Plan.max_elevation_time', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='downlink_center_frequency_hz', full_name='stellarstation.api.v1.Plan.downlink_center_frequency_hz', index=10,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uplink_center_frequency_hz', full_name='stellarstation.api.v1.Plan.uplink_center_frequency_hz', index=11,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='telmetry_metadata', full_name='stellarstation.api.v1.Plan.telmetry_metadata', index=12,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PLAN_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2608,
  serialized_end=3222,
)


_ADDTLEREQUEST = _descriptor.Descriptor(
  name='AddTleRequest',
  full_name='stellarstation.api.v1.AddTleRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='satellite_id', full_name='stellarstation.api.v1.AddTleRequest.satellite_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tle', full_name='stellarstation.api.v1.AddTleRequest.tle', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3224,
  serialized_end=3308,
)


_ADDTLERESPONSE = _descriptor.Descriptor(
  name='AddTleResponse',
  full_name='stellarstation.api.v1.AddTleResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3310,
  serialized_end=3326,
)


_GETTLEREQUEST = _descriptor.Descriptor(
  name='GetTleRequest',
  full_name='stellarstation.api.v1.GetTleRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='satellite_id', full_name='stellarstation.api.v1.GetTleRequest.satellite_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3328,
  serialized_end=3365,
)


_GETTLERESPONSE = _descriptor.Descriptor(
  name='GetTleResponse',
  full_name='stellarstation.api.v1.GetTleResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tle', full_name='stellarstation.api.v1.GetTleResponse.tle', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3367,
  serialized_end=3430,
)

_SATELLITESTREAMREQUEST.fields_by_name['send_satellite_commands_request'].message_type = _SENDSATELLITECOMMANDSREQUEST
_SATELLITESTREAMREQUEST.fields_by_name['accepted_framing'].enum_type = _FRAMING
_SATELLITESTREAMREQUEST.oneofs_by_name['Request'].fields.append(
  _SATELLITESTREAMREQUEST.fields_by_name['send_satellite_commands_request'])
_SATELLITESTREAMREQUEST.fields_by_name['send_satellite_commands_request'].containing_oneof = _SATELLITESTREAMREQUEST.oneofs_by_name['Request']
_SATELLITESTREAMRESPONSE.fields_by_name['receive_telemetry_response'].message_type = _RECEIVETELEMETRYRESPONSE
_SATELLITESTREAMRESPONSE.fields_by_name['stream_event'].message_type = _STREAMEVENT
_SATELLITESTREAMRESPONSE.oneofs_by_name['Response'].fields.append(
  _SATELLITESTREAMRESPONSE.fields_by_name['receive_telemetry_response'])
_SATELLITESTREAMRESPONSE.fields_by_name['receive_telemetry_response'].containing_oneof = _SATELLITESTREAMRESPONSE.oneofs_by_name['Response']
_SATELLITESTREAMRESPONSE.oneofs_by_name['Response'].fields.append(
  _SATELLITESTREAMRESPONSE.fields_by_name['stream_event'])
_SATELLITESTREAMRESPONSE.fields_by_name['stream_event'].containing_oneof = _SATELLITESTREAMRESPONSE.oneofs_by_name['Response']
_RECEIVETELEMETRYRESPONSE.fields_by_name['telemetry'].message_type = _TELEMETRY
_TELEMETRY.fields_by_name['framing'].enum_type = _FRAMING
_TELEMETRY.fields_by_name['time_first_byte_received'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TELEMETRY.fields_by_name['time_last_byte_received'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PLANMONITORINGEVENT.fields_by_name['ground_station_configuration'].message_type = stellarstation_dot_api_dot_v1_dot_monitoring_dot_monitoring__pb2._GROUNDSTATIONCONFIGURATION
_PLANMONITORINGEVENT.fields_by_name['ground_station_state'].message_type = stellarstation_dot_api_dot_v1_dot_monitoring_dot_monitoring__pb2._GROUNDSTATIONSTATE
_PLANMONITORINGEVENT.oneofs_by_name['Info'].fields.append(
  _PLANMONITORINGEVENT.fields_by_name['ground_station_configuration'])
_PLANMONITORINGEVENT.fields_by_name['ground_station_configuration'].containing_oneof = _PLANMONITORINGEVENT.oneofs_by_name['Info']
_PLANMONITORINGEVENT.oneofs_by_name['Info'].fields.append(
  _PLANMONITORINGEVENT.fields_by_name['ground_station_state'])
_PLANMONITORINGEVENT.fields_by_name['ground_station_state'].containing_oneof = _PLANMONITORINGEVENT.oneofs_by_name['Info']
_STREAMEVENT_COMMANDSENTFROMGROUNDSTATION.containing_type = _STREAMEVENT
_STREAMEVENT.fields_by_name['command_sent'].message_type = _STREAMEVENT_COMMANDSENTFROMGROUNDSTATION
_STREAMEVENT.fields_by_name['plan_monitoring_event'].message_type = _PLANMONITORINGEVENT
_STREAMEVENT.oneofs_by_name['Event'].fields.append(
  _STREAMEVENT.fields_by_name['command_sent'])
_STREAMEVENT.fields_by_name['command_sent'].containing_oneof = _STREAMEVENT.oneofs_by_name['Event']
_STREAMEVENT.oneofs_by_name['Event'].fields.append(
  _STREAMEVENT.fields_by_name['plan_monitoring_event'])
_STREAMEVENT.fields_by_name['plan_monitoring_event'].containing_oneof = _STREAMEVENT.oneofs_by_name['Event']
_LISTUPCOMINGAVAILABLEPASSESRESPONSE.fields_by_name['pass'].message_type = _PASS
_RESERVEPASSRESPONSE.fields_by_name['plan'].message_type = _PLAN
_LISTPLANSREQUEST.fields_by_name['aos_after'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTPLANSREQUEST.fields_by_name['aos_before'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTPLANSRESPONSE.fields_by_name['plan'].message_type = _PLAN
_PASS.fields_by_name['aos_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PASS.fields_by_name['los_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PASS.fields_by_name['max_elevation_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TELEMETRYMETADATA.fields_by_name['data_type'].enum_type = _TELEMETRYMETADATA_DATATYPE
_TELEMETRYMETADATA_DATATYPE.containing_type = _TELEMETRYMETADATA
_PLAN.fields_by_name['status'].enum_type = _PLAN_STATUS
_PLAN.fields_by_name['aos_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PLAN.fields_by_name['los_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PLAN.fields_by_name['max_elevation_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PLAN.fields_by_name['telmetry_metadata'].message_type = _TELEMETRYMETADATA
_PLAN_STATUS.containing_type = _PLAN
_ADDTLEREQUEST.fields_by_name['tle'].message_type = stellarstation_dot_api_dot_v1_dot_orbit_dot_orbit__pb2._TLE
_GETTLERESPONSE.fields_by_name['tle'].message_type = stellarstation_dot_api_dot_v1_dot_orbit_dot_orbit__pb2._TLE
DESCRIPTOR.message_types_by_name['SatelliteStreamRequest'] = _SATELLITESTREAMREQUEST
DESCRIPTOR.message_types_by_name['SendSatelliteCommandsRequest'] = _SENDSATELLITECOMMANDSREQUEST
DESCRIPTOR.message_types_by_name['SatelliteStreamResponse'] = _SATELLITESTREAMRESPONSE
DESCRIPTOR.message_types_by_name['ReceiveTelemetryResponse'] = _RECEIVETELEMETRYRESPONSE
DESCRIPTOR.message_types_by_name['Telemetry'] = _TELEMETRY
DESCRIPTOR.message_types_by_name['PlanMonitoringEvent'] = _PLANMONITORINGEVENT
DESCRIPTOR.message_types_by_name['StreamEvent'] = _STREAMEVENT
DESCRIPTOR.message_types_by_name['CancelPlanRequest'] = _CANCELPLANREQUEST
DESCRIPTOR.message_types_by_name['CancelPlanResponse'] = _CANCELPLANRESPONSE
DESCRIPTOR.message_types_by_name['ListUpcomingAvailablePassesRequest'] = _LISTUPCOMINGAVAILABLEPASSESREQUEST
DESCRIPTOR.message_types_by_name['ListUpcomingAvailablePassesResponse'] = _LISTUPCOMINGAVAILABLEPASSESRESPONSE
DESCRIPTOR.message_types_by_name['ReservePassRequest'] = _RESERVEPASSREQUEST
DESCRIPTOR.message_types_by_name['ReservePassResponse'] = _RESERVEPASSRESPONSE
DESCRIPTOR.message_types_by_name['ListPlansRequest'] = _LISTPLANSREQUEST
DESCRIPTOR.message_types_by_name['ListPlansResponse'] = _LISTPLANSRESPONSE
DESCRIPTOR.message_types_by_name['Pass'] = _PASS
DESCRIPTOR.message_types_by_name['TelemetryMetadata'] = _TELEMETRYMETADATA
DESCRIPTOR.message_types_by_name['Plan'] = _PLAN
DESCRIPTOR.message_types_by_name['AddTleRequest'] = _ADDTLEREQUEST
DESCRIPTOR.message_types_by_name['AddTleResponse'] = _ADDTLERESPONSE
DESCRIPTOR.message_types_by_name['GetTleRequest'] = _GETTLEREQUEST
DESCRIPTOR.message_types_by_name['GetTleResponse'] = _GETTLERESPONSE
DESCRIPTOR.enum_types_by_name['Framing'] = _FRAMING
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SatelliteStreamRequest = _reflection.GeneratedProtocolMessageType('SatelliteStreamRequest', (_message.Message,), dict(
  DESCRIPTOR = _SATELLITESTREAMREQUEST,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.SatelliteStreamRequest)
  ))
_sym_db.RegisterMessage(SatelliteStreamRequest)

SendSatelliteCommandsRequest = _reflection.GeneratedProtocolMessageType('SendSatelliteCommandsRequest', (_message.Message,), dict(
  DESCRIPTOR = _SENDSATELLITECOMMANDSREQUEST,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.SendSatelliteCommandsRequest)
  ))
_sym_db.RegisterMessage(SendSatelliteCommandsRequest)

SatelliteStreamResponse = _reflection.GeneratedProtocolMessageType('SatelliteStreamResponse', (_message.Message,), dict(
  DESCRIPTOR = _SATELLITESTREAMRESPONSE,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.SatelliteStreamResponse)
  ))
_sym_db.RegisterMessage(SatelliteStreamResponse)

ReceiveTelemetryResponse = _reflection.GeneratedProtocolMessageType('ReceiveTelemetryResponse', (_message.Message,), dict(
  DESCRIPTOR = _RECEIVETELEMETRYRESPONSE,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.ReceiveTelemetryResponse)
  ))
_sym_db.RegisterMessage(ReceiveTelemetryResponse)

Telemetry = _reflection.GeneratedProtocolMessageType('Telemetry', (_message.Message,), dict(
  DESCRIPTOR = _TELEMETRY,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.Telemetry)
  ))
_sym_db.RegisterMessage(Telemetry)

PlanMonitoringEvent = _reflection.GeneratedProtocolMessageType('PlanMonitoringEvent', (_message.Message,), dict(
  DESCRIPTOR = _PLANMONITORINGEVENT,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.PlanMonitoringEvent)
  ))
_sym_db.RegisterMessage(PlanMonitoringEvent)

StreamEvent = _reflection.GeneratedProtocolMessageType('StreamEvent', (_message.Message,), dict(

  CommandSentFromGroundStation = _reflection.GeneratedProtocolMessageType('CommandSentFromGroundStation', (_message.Message,), dict(
    DESCRIPTOR = _STREAMEVENT_COMMANDSENTFROMGROUNDSTATION,
    __module__ = 'stellarstation.api.v1.stellarstation_pb2'
    # @@protoc_insertion_point(class_scope:stellarstation.api.v1.StreamEvent.CommandSentFromGroundStation)
    ))
  ,
  DESCRIPTOR = _STREAMEVENT,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.StreamEvent)
  ))
_sym_db.RegisterMessage(StreamEvent)
_sym_db.RegisterMessage(StreamEvent.CommandSentFromGroundStation)

CancelPlanRequest = _reflection.GeneratedProtocolMessageType('CancelPlanRequest', (_message.Message,), dict(
  DESCRIPTOR = _CANCELPLANREQUEST,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.CancelPlanRequest)
  ))
_sym_db.RegisterMessage(CancelPlanRequest)

CancelPlanResponse = _reflection.GeneratedProtocolMessageType('CancelPlanResponse', (_message.Message,), dict(
  DESCRIPTOR = _CANCELPLANRESPONSE,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.CancelPlanResponse)
  ))
_sym_db.RegisterMessage(CancelPlanResponse)

ListUpcomingAvailablePassesRequest = _reflection.GeneratedProtocolMessageType('ListUpcomingAvailablePassesRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTUPCOMINGAVAILABLEPASSESREQUEST,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.ListUpcomingAvailablePassesRequest)
  ))
_sym_db.RegisterMessage(ListUpcomingAvailablePassesRequest)

ListUpcomingAvailablePassesResponse = _reflection.GeneratedProtocolMessageType('ListUpcomingAvailablePassesResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTUPCOMINGAVAILABLEPASSESRESPONSE,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.ListUpcomingAvailablePassesResponse)
  ))
_sym_db.RegisterMessage(ListUpcomingAvailablePassesResponse)

ReservePassRequest = _reflection.GeneratedProtocolMessageType('ReservePassRequest', (_message.Message,), dict(
  DESCRIPTOR = _RESERVEPASSREQUEST,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.ReservePassRequest)
  ))
_sym_db.RegisterMessage(ReservePassRequest)

ReservePassResponse = _reflection.GeneratedProtocolMessageType('ReservePassResponse', (_message.Message,), dict(
  DESCRIPTOR = _RESERVEPASSRESPONSE,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.ReservePassResponse)
  ))
_sym_db.RegisterMessage(ReservePassResponse)

ListPlansRequest = _reflection.GeneratedProtocolMessageType('ListPlansRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTPLANSREQUEST,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.ListPlansRequest)
  ))
_sym_db.RegisterMessage(ListPlansRequest)

ListPlansResponse = _reflection.GeneratedProtocolMessageType('ListPlansResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTPLANSRESPONSE,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.ListPlansResponse)
  ))
_sym_db.RegisterMessage(ListPlansResponse)

Pass = _reflection.GeneratedProtocolMessageType('Pass', (_message.Message,), dict(
  DESCRIPTOR = _PASS,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.Pass)
  ))
_sym_db.RegisterMessage(Pass)

TelemetryMetadata = _reflection.GeneratedProtocolMessageType('TelemetryMetadata', (_message.Message,), dict(
  DESCRIPTOR = _TELEMETRYMETADATA,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.TelemetryMetadata)
  ))
_sym_db.RegisterMessage(TelemetryMetadata)

Plan = _reflection.GeneratedProtocolMessageType('Plan', (_message.Message,), dict(
  DESCRIPTOR = _PLAN,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.Plan)
  ))
_sym_db.RegisterMessage(Plan)

AddTleRequest = _reflection.GeneratedProtocolMessageType('AddTleRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDTLEREQUEST,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.AddTleRequest)
  ))
_sym_db.RegisterMessage(AddTleRequest)

AddTleResponse = _reflection.GeneratedProtocolMessageType('AddTleResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDTLERESPONSE,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.AddTleResponse)
  ))
_sym_db.RegisterMessage(AddTleResponse)

GetTleRequest = _reflection.GeneratedProtocolMessageType('GetTleRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETTLEREQUEST,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.GetTleRequest)
  ))
_sym_db.RegisterMessage(GetTleRequest)

GetTleResponse = _reflection.GeneratedProtocolMessageType('GetTleResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETTLERESPONSE,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.GetTleResponse)
  ))
_sym_db.RegisterMessage(GetTleResponse)


DESCRIPTOR._options = None

_STELLARSTATIONSERVICE = _descriptor.ServiceDescriptor(
  name='StellarStationService',
  full_name='stellarstation.api.v1.StellarStationService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=3492,
  serialized_end=4259,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListPlans',
    full_name='stellarstation.api.v1.StellarStationService.ListPlans',
    index=0,
    containing_service=None,
    input_type=_LISTPLANSREQUEST,
    output_type=_LISTPLANSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='CancelPlan',
    full_name='stellarstation.api.v1.StellarStationService.CancelPlan',
    index=1,
    containing_service=None,
    input_type=_CANCELPLANREQUEST,
    output_type=_CANCELPLANRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListUpcomingAvailablePasses',
    full_name='stellarstation.api.v1.StellarStationService.ListUpcomingAvailablePasses',
    index=2,
    containing_service=None,
    input_type=_LISTUPCOMINGAVAILABLEPASSESREQUEST,
    output_type=_LISTUPCOMINGAVAILABLEPASSESRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='OpenSatelliteStream',
    full_name='stellarstation.api.v1.StellarStationService.OpenSatelliteStream',
    index=3,
    containing_service=None,
    input_type=_SATELLITESTREAMREQUEST,
    output_type=_SATELLITESTREAMRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ReservePass',
    full_name='stellarstation.api.v1.StellarStationService.ReservePass',
    index=4,
    containing_service=None,
    input_type=_RESERVEPASSREQUEST,
    output_type=_RESERVEPASSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddTle',
    full_name='stellarstation.api.v1.StellarStationService.AddTle',
    index=5,
    containing_service=None,
    input_type=_ADDTLEREQUEST,
    output_type=_ADDTLERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetTle',
    full_name='stellarstation.api.v1.StellarStationService.GetTle',
    index=6,
    containing_service=None,
    input_type=_GETTLEREQUEST,
    output_type=_GETTLERESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_STELLARSTATIONSERVICE)

DESCRIPTOR.services_by_name['StellarStationService'] = _STELLARSTATIONSERVICE

# @@protoc_insertion_point(module_scope)
